@@ -68,7 +68,7 @@ class ranaModule:
   def drawScreenOverlay(self, cr):
     """Draw overlay that's on top of all maps"""
     pass
-  def handleMessage(self, message):
+  def handleMessage(self, message, type, args):
     """Handles a message from another module, or in response to user action"""
     pass
   def dragEvent(self,startX,startY,dx,dy,x,y):
