@@ -411,6 +411,20 @@ class menus(ranaModule):
         label.lower(),                     # icon
         'set:mode:'+mode+"|set:menu:None") # action
 
+  def setupSearchWhereMenu(self):
+    self.clearMenu('searchWhere')
+    self.addItem('searchWhere', 'view#near', 'generic', 'ms:search:setWhere:view|set:menu:search')
+    self.addItem('searchWhere', 'position#near', 'generic', 'ms:search:setWhere:position|set:menu:search')
+    """
+    TODO:
+    * near tracklog
+     * start
+     * end
+     * AROUND (is this doable ? maybe use points from perElevList...)
+    * near address
+    * near POI (when POI rework is finished)
+    """
+
   def setupSearchMenus(self):
     """Create a load of menus that are just filters for OSM tags"""
     f = open("data/search_menu.txt", "r")
@@ -547,7 +561,7 @@ class menus(ranaModule):
 #    self.addItem('main', 'waypoints', 'waypoints', 'set:menu:waypoints_categories')
     self.addItem('main', 'route', 'route', 'set:menu:route')
     self.addItem('main', 'POI', 'poi', 'set:menu:poi')
-    self.addItem('main', 'search', 'business', 'set:menu:search')
+    self.addItem('main', 'search', 'business', 'set:menu:searchWhere')
     #self.addItem('main', 'view', 'view', 'set:menu:view')
     self.addItem('main', 'options', 'options', 'set:menu:options')
     self.addItem('main', 'download', 'download', 'set:menu:data')
@@ -558,6 +572,7 @@ class menus(ranaModule):
 #    self.addItem('main', 'fullscreen', 'fullscreen', 'menu:fullscreenTogle|set:menu:None')
     self.setupTransportMenu()
     self.setupSearchMenus()
+    self.setupSearchWhereMenu()
     self.setupMaplayerMenus()
     self.setupPoiMenu()
     self.setupDataMenu()
@@ -841,7 +856,7 @@ class menus(ranaModule):
     self.set("menu",None)
     self.userConfig = self.m.get('config', None).userConfig
 
-  def handleMessage(self, message):
+  def handleMessage(self, message, type, args):
     messageList = message.split('#')
     message = messageList[0]
     if (message == "rebootDataMenu"):
