@@ -224,7 +224,7 @@ class options(ranaModule):
   def optionsFilename(self):
     return("data/options.bin")
   
-  def handleMessage(self, message):
+  def handleMessage(self, message, type, args):
     if(message == "up"):
       if(self.scroll > 0):
         self.scroll -= 1
